@@ -1,10 +1,12 @@
--- Copyright (c) 2010, David Amos. All rights reserved.
+-- Copyright (c) 2010-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE FlexibleInstances, MultiParamTypeClasses #-}
 
 -- |A module defining the algebra of non-commutative polynomials over a field k
 module Math.Algebras.NonCommutative where
 
+import Prelude hiding ( (*>) )
+
 import Math.Algebra.Field.Base hiding (powers)
 import Math.Algebras.VectorSpace
 import Math.Algebras.TensorProduct
@@ -30,7 +32,7 @@ instance Mon (NonComMonomial v) where
     mmult (NCM i xs) (NCM j ys) = NCM (i+j) (xs++ys)
 
 instance (Eq k, Num k, Ord v) => Algebra k (NonComMonomial v) where
-    unit 0 = zero -- V []
+    unit 0 = zerov -- V []
     unit x = V [(munit,x)]
     mult = nf . fmap (\(a,b) -> a `mmult` b)
 
