@@ -1,4 +1,4 @@
--- Copyright (c) David Amos, 2010-2012. All rights reserved.
+-- Copyright (c) David Amos, 2010-2015. All rights reserved.
 
 {-# LANGUAGE MultiParamTypeClasses, NoMonomorphismRestriction #-}
 {-# LANGUAGE FlexibleInstances, TypeSynonymInstances #-}
@@ -8,6 +8,8 @@
 -- - specifically algebra, coalgebra, bialgebra, Hopf algebra, module, comodule
 module Math.Algebras.Structures where
 
+import Prelude hiding ( (*>) )
+
 import Math.Algebras.VectorSpace
 import Math.Algebras.TensorProduct
 
@@ -103,7 +105,7 @@ instance (Eq k, Num k, Ord a, Ord b, Algebra k a, Algebra k b) => Algebra k (DSu
     mult = linear mult'
         where mult' (Left a1, Left a2) = i1 $ mult $ return (a1,a2)
               mult' (Right b1, Right b2) = i2 $ mult $ return (b1,b2)
-              mult' _ = zero
+              mult' _ = zerov
 -- This is the product algebra, which is the product in the category of algebras
 -- 1 = (1,1)
 -- (a1,b1) * (a2,b2) = (a1*a2, b1*b2)
