@@ -5,6 +5,8 @@
 -- |A module defining the tensor algebra, symmetric algebra, exterior (or alternating) algebra, and tensor coalgebra
 module Math.Algebras.TensorAlgebra where
 
+import Prelude hiding ( (*>) )
+
 import qualified Data.List as L
 
 import Math.Algebras.VectorSpace
@@ -195,7 +197,7 @@ instance (Eq k, Num k, Ord a) => Algebra k (ExteriorAlgebra a) where
     mult xy = nf $ xy >>= (\(Ext i xs, Ext j ys) -> signedMerge 1 (0,[]) (i,xs) (j,ys))
         where signedMerge s (k,zs) (i,x:xs) (j,y:ys) =
                   case compare x y of
-                  EQ -> zero
+                  EQ -> zerov
                   LT -> signedMerge s (k+1,x:zs) (i-1,xs) (j,y:ys)
                   GT -> let s' = if even i then s else -s -- we had to commute y past x:xs, with i sign changes
                         in signedMerge s' (k+1,y:zs) (i,x:xs) (j-1,ys)
