@@ -1,4 +1,4 @@
--- Copyright (c) 2012, David Amos. All rights reserved.
+-- Copyright (c) 2012-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE MultiParamTypeClasses, FlexibleInstances, NoMonomorphismRestriction, ScopedTypeVariables, DeriveFunctor #-}
 
@@ -34,6 +34,8 @@ module Math.Combinatorics.CombinatorialHopfAlgebra where
 -- Lie Algebras and Hopf Algebras
 -- Michiel Hazewinkel, Nadiya Gubareni, V.V.Kirichenko
 
+import Prelude hiding ( (*>) )
+
 import Data.List as L
 import Data.Maybe (fromJust)
 import qualified Data.Set as S
@@ -198,17 +200,17 @@ mu (set,po) x y = mu' x y where
 
 -- |Convert an element of SSym represented in the monomial basis to the fundamental basis
 ssymMtoF :: (Eq k, Num k) => Vect k SSymM -> Vect k SSymF
-ssymMtoF = linear ssymMtoF'
-    where ssymMtoF' (SSymM u) = sumv [mu (set,po) u v *> return (SSymF v) | v <- set, po u v]
-              where set = L.permutations u
-                    po = weakOrder
+ssymMtoF = linear ssymMtoF' where
+    ssymMtoF' (SSymM u) = sumv [mu (set,po) u v *> return (SSymF v) | v <- set, po u v]
+        where set = L.permutations u
+              po = weakOrder
 
 -- |Convert an element of SSym represented in the fundamental basis to the monomial basis
 ssymFtoM :: (Eq k, Num k) => Vect k SSymF -> Vect k SSymM
-ssymFtoM = linear ssymFtoM'
-    where ssymFtoM' (SSymF u) = sumv [return (SSymM v) | v <- set, po u v]
-              where set = L.permutations u
-                    po = weakOrder
+ssymFtoM = linear ssymFtoM' where
+    ssymFtoM' (SSymF u) = sumv [return (SSymM v) | v <- set, po u v]
+        where set = L.permutations u
+              po = weakOrder
 
 -- (p,q)-shuffles: permutations of [1..p+q] having at most one descent, at position p
 -- denoted S^{(p,q)} in Aguiar&Sottile
@@ -457,16 +459,16 @@ tamariOrder u v = weakOrder (minPerm u) (minPerm v)
 
 -- |Convert an element of YSym represented in the monomial basis to the fundamental basis
 ysymMtoF :: (Eq k, Num k) => Vect k YSymM -> Vect k (YSymF ())
-ysymMtoF = linear ysymMtoF'
-    where ysymMtoF' (YSymM t) = sumv [mu (set,po) t s *> return (YSymF s) | s <- set]
-              where po = tamariOrder
-                    set = tamariUpSet t -- [s | s <- trees (nodecount t), t `tamariOrder` s]
+ysymMtoF = linear ysymMtoF' where
+    ysymMtoF' (YSymM t) = sumv [mu (set,po) t s *> return (YSymF s) | s <- set]
+        where po = tamariOrder
+              set = tamariUpSet t -- [s | s <- trees (nodecount t), t `tamariOrder` s]
 
 -- |Convert an element of YSym represented in the fundamental basis to the monomial basis
 ysymFtoM :: (Eq k, Num k) => Vect k (YSymF ()) -> Vect k YSymM
-ysymFtoM = linear ysymFtoM'
-    where ysymFtoM' (YSymF t) = sumv [return (YSymM s) | s <- tamariUpSet t]
-                            -- sumv [return (YSymM s) | s <- trees (nodecount t), t `tamariOrder` s]
+ysymFtoM = linear ysymFtoM' where
+    ysymFtoM' (YSymF t) = sumv [return (YSymM s) | s <- tamariUpSet t]
+                       -- sumv [return (YSymM s) | s <- trees (nodecount t), t `tamariOrder` s]
 
 
 instance (Eq k, Num k) => Algebra k YSymM where
@@ -565,13 +567,13 @@ qsymF xs | all (>0) xs = return (QSymF xs)
 
 -- |Convert an element of QSym represented in the monomial basis to the fundamental basis
 qsymMtoF :: (Eq k, Num k) => Vect k QSymM -> Vect k QSymF
-qsymMtoF = linear qsymMtoF'
-    where qsymMtoF' (QSymM alpha) = sumv [(-1) ^ (length beta - length alpha) *> return (QSymF beta) | beta <- refinements alpha]
+qsymMtoF = linear qsymMtoF' where
+    qsymMtoF' (QSymM alpha) = sumv [(-1) ^ (length beta - length alpha) *> return (QSymF beta) | beta <- refinements alpha]
 
 -- |Convert an element of QSym represented in the fundamental basis to the monomial basis
 qsymFtoM :: (Eq k, Num k) => Vect k QSymF -> Vect k QSymM
-qsymFtoM = linear qsymFtoM'
-    where qsymFtoM' (QSymF alpha) = sumv [return (QSymM beta) | beta <- refinements alpha] -- ie beta <- up-set of alpha
+qsymFtoM = linear qsymFtoM' where
+    qsymFtoM' (QSymF alpha) = sumv [return (QSymM beta) | beta <- refinements alpha] -- ie beta <- up-set of alpha
 
 instance (Eq k, Num k) => Algebra k QSymF where
     unit x = x *> return (QSymF [])
@@ -592,13 +594,13 @@ instance (Eq k, Num k) => HopfAlgebra k QSymF where
 -- the above induces Hopf algebra structure on quasi-symmetric functions via
 -- m_alpha -> sum [product (zipWith (^) (map x_ is) alpha | is <- combinationsOf k [] ] where k = length alpha
 
-xvars n = [glexvar ("x" ++ show i) | i <- [1..n] ]
+-- xvars n = [glexvar ("x" ++ show i) | i <- [1..n] ]
 
 -- |@qsymPoly n is@ is the quasi-symmetric polynomial in n variables for the indices is. (This corresponds to the
 -- monomial basis for QSym.) For example, qsymPoly 3 [2,1] == x1^2*x2+x1^2*x3+x2^2*x3.
 qsymPoly :: Int -> [Int] -> GlexPoly Q String
 qsymPoly n is = sum [product (zipWith (^) xs' is) | xs' <- combinationsOf r xs]
-    where xs = xvars n
+    where xs = [glexvar ("x" ++ show i) | i <- [1..n] ]
           r = length is
 
 
@@ -776,6 +778,7 @@ descendingTreeMap = nf . fmap (YSymF . shape .  descendingTree')
 
 -- "inverse" for descendingTree
 -- These are the maps called gamma in Loday.pdf
+-- or are they? - these give the min and max inverse images in the lexicographic order, rather than the weak order?
 minPerm t = minPerm' (lrCountTree t)
     where minPerm' E = []
           minPerm' (T l (lc,rc) r) = minPerm' l ++ [lc+rc+1] ++ map (+lc) (minPerm' r)
@@ -810,10 +813,9 @@ descents xs = map (+1) $ L.elemIndices True $ zipWith (>) xs (tail xs)
 
 -- The composition of [1..n] obtained by treating each descent as a cut
 descentComposition [] = []
-descentComposition xs = dc $ zipWith (>) xs (tail xs) ++ [False]
-    where dc bs = case break id bs of
-                  (ls,r:rs) -> (length ls + 1) : dc rs
-                  (ls,[]) -> [length ls]
+descentComposition xs = descComp 0 xs where
+    descComp c (x1:x2:xs) = if x1 < x2 then descComp (c+1) (x2:xs) else (c+1) : descComp 0 (x2:xs)
+    descComp c [x] = [c+1]
 
 -- |Given a permutation of [1..n], its descents are those positions where the next number is less than the previous number.
 -- For example, the permutation [2,3,5,1,6,4] has descents from 5 to 1 and from 6 to 4. The descents can be regarded as cutting
