@@ -2,7 +2,8 @@
 
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
 
--- |A module defining the field Q of rationals and the small finite fields F2, F3, F4, F5, F7, F8, F9, F11, F13, F16, F17, F19, F23, F25.
+-- |A module defining the field Q of rationals and the small finite fields (Galois fields)
+-- F2, F3, F4, F5, F7, F8, F9, F11, F13, F16, F17, F19, F23, F25.
 --
 -- Given a prime power q, Fq is the type representing elements of the field (eg @F4@),
 -- fq is a list of the elements of the field, beginning 0,1,... (eg @f4@),
@@ -380,10 +381,10 @@ a9 = F9 0x100
 
 instance Num F9 where
     F9 x + F9 y = F9 $ z1 + z0
-        where z = x+y; z1 = (z .&. 0xff00) `mod` 0x300; z0 = (z .&. 0xff) `mod` 3
+        where z = x+y; z1 = (z .&. 0xff00) `rem` 0x300; z0 = (z .&. 0xff) `rem` 3
     negate (F9 x) = F9 $ z1 + z0
-        where z = 0x303 - x; z1 = (z .&. 0xff00) `mod` 0x300; z0 = (z .&. 0xff) `mod` 3
-    F9 x * F9 y = F9 $ ((z2 + z1) `mod` 0x300) + ((z2 + z0) `mod` 3) 
+        where z = 0x303 - x; z1 = (z .&. 0xff00) `rem` 0x300; z0 = (z .&. 0xff) `rem` 3
+    F9 x * F9 y = F9 $ ((z2 + z1) `rem` 0x300) + ((z2 + z0) `rem` 3) 
         where z = x*y; z2 = z .&. 0xff0000; z1 = z .&. 0xff00; z0 = z .&. 0xff
         -- Explanation: We are substituting x^2 = x+1.
         -- We could do z2 `shiftR` 8 and z2 `shiftR` 16
@@ -470,10 +471,10 @@ a25 = F25 0x100
 
 instance Num F25 where
     F25 x + F25 y = F25 $ z1 + z0
-        where z = x+y; z1 = (z .&. 0xff00) `mod` 0x500; z0 = (z .&. 0xff) `mod` 5
+        where z = x+y; z1 = (z .&. 0xff00) `rem` 0x500; z0 = (z .&. 0xff) `rem` 5
     negate (F25 x) = F25 $ z1 + z0
-        where z = 0x505 - x; z1 = (z .&. 0xff00) `mod` 0x500; z0 = (z .&. 0xff) `mod` 5
-    F25 x * F25 y = F25 $ ((z2 + z1) `mod` 0x500) + ((3*z2 + z0) `mod` 5) 
+        where z = 0x505 - x; z1 = (z .&. 0xff00) `rem` 0x500; z0 = (z .&. 0xff) `rem` 5
+    F25 x * F25 y = F25 $ ((z2 + z1) `rem` 0x500) + ((3*z2 + z0) `rem` 5) 
         where z = x*y; z2 = z .&. 0xff0000; z1 = z .&. 0xff00; z0 = z .&. 0xff
         -- Explanation: We are substituting x^2 = x+3.
         -- We could do z2 `shiftR` 8 and z2 `shiftR` 16
