@@ -1,4 +1,4 @@
--- Copyright (c) 2010, David Amos. All rights reserved.
+-- Copyright (c) 2010-2015, David Amos. All rights reserved.
 
 {-# LANGUAGE MultiParamTypeClasses, TypeFamilies, FlexibleInstances, EmptyDataDecls #-}
 
@@ -6,6 +6,8 @@
 -- (specifically, knot invariants).
 module Math.QuantumAlgebra.Tangle where
 
+import Prelude hiding ( (*>) )
+
 -- import qualified Data.List as L
 
 import Math.Algebras.VectorSpace
@@ -15,7 +17,7 @@ import Math.Algebras.Structures
 import Math.Algebra.Field.Base
 import Math.Algebras.LaurentPoly
 
-import Math.QuantumAlgebra.TensorCategory
+import Math.QuantumAlgebra.TensorCategory hiding (Vect)
 
 
 instance Mon [a] where
@@ -25,7 +27,7 @@ instance Mon [a] where
 -- type TensorAlgebra k a = Vect k [a]
 
 instance (Eq k, Num k, Ord a) => Algebra k [a] where
-    unit 0 = zero -- V []
+    unit 0 = zerov -- V []
     unit x = V [(munit,x)]
     mult = nf . fmap (\(a,b) -> a `mmult` b)
 
@@ -37,7 +39,7 @@ instance (Eq k, Num k, Ord a) => Algebra k [a] where
 
 data Tangle
 
-instance Category Tangle where
+instance MCategory Tangle where
     data Ob Tangle = OT Int deriving (Eq,Ord,Show)
     data Ar Tangle = IdT Int
                    | CapT
@@ -71,7 +73,7 @@ instance Category Tangle where
 --    a >>> b | target a == source b = SeqT a b
     a >>> b | target a == source b = SeqT [a,b]
 
-instance TensorCategory Tangle where
+instance Monoidal Tangle where
     tunit = OT 0
     tob (OT a) (OT b) = OT (a+b)
 --    tar a b = ParT a b
@@ -93,7 +95,7 @@ cap [] = return [Plus, Minus] <+> (-q^2) *> return [Minus, Plus]
 cup :: [Oriented] -> TangleRep [Oriented]
 cup [Plus, Minus] = (-q'^2) *> return []
 cup [Minus, Plus] = return []
-cup _ = zero
+cup _ = zerov
 
 -- also called xminus
 over :: [Oriented] -> TangleRep [Oriented]
